.. Normalization documentation master file, created by
   sphinx-quickstart on Tue Jan 2 11:01:01 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Normalization's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents
   
   installation
   loading
   dark_field_correction
   normalization
   cropping_data
   retrieve_normalized_data
   export_data

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
